import { Utensils, Bath, Scissors, Home, RefreshCw, Drill, ArrowRight } from "lucide-react";
import { motion } from "framer-motion";

interface ServiceCardProps {
  icon: React.ReactNode;
  title: string;
  description: string;
  index: number;
  isPopular?: boolean;
}

function ServiceCard({ icon, title, description, index, isPopular }: ServiceCardProps) {
  return (
    <div 
      className={`fade-in stagger-${Math.min(index + 1, 3)} bg-white rounded-2xl overflow-hidden shadow-lg transition-all duration-300 border group relative cursor-pointer hover-lift ${
        isPopular ? 'border-accent/30 ring-2 ring-accent/20' : 'border-gray-100'
      }`}
    >
      <div className="absolute top-0 left-0 w-full h-1 bg-accent transform scale-x-0 group-hover:scale-x-100 origin-left transition-transform duration-300"></div>
      <div className="p-6 sm:p-8">
        {isPopular && (
          <div className="mb-4">
            <span className="bg-accent text-primary text-xs font-bold px-3 py-1.5 rounded-full shadow-md inline-block">
              ⭐ Most Popular
            </span>
          </div>
        )}
        
        <motion.div 
          className="bg-primary/10 text-primary w-16 h-16 rounded-2xl flex items-center justify-center mb-6 group-hover:bg-primary group-hover:text-white transition-all duration-300 group-hover:shadow-lg"
          whileHover={{ scale: 1.1, rotate: 5 }}
          animate={{ 
            boxShadow: "0 0 0 0 rgba(59, 130, 246, 0)"
          }}
          whileInView={{
            boxShadow: [
              "0 0 0 0 rgba(59, 130, 246, 0)",
              "0 0 0 10px rgba(59, 130, 246, 0.1)",
              "0 0 0 0 rgba(59, 130, 246, 0)"
            ]
          }}
          transition={{ duration: 2, repeat: Infinity, repeatDelay: 3 }}
        >
          {icon}
        </motion.div>
        
        <h3 className="text-xl font-bold mb-4 text-primary group-hover:text-accent transition-colors duration-300">{title}</h3>
        <p className="text-gray-600 mb-6 leading-relaxed">{description}</p>
        <a 
          href="#contact" 
          className="text-primary hover:text-accent font-semibold inline-flex items-center transition-all duration-300"
          aria-label={`Get quote for ${title.toLowerCase()}`}
        >
          Learn More
          <ArrowRight className="w-4 h-4 ml-2 transform translate-x-0 group-hover:translate-x-2 transition-transform duration-300" />
        </a>
      </div>
    </div>
  );
}

export default function ServicesSection() {
  const services = [
    {
      icon: <Utensils className="h-8 w-8" />,
      title: "Kitchen Countertops",
      description: "Custom kitchen countertop installation in granite, marble, quartz, and other premium materials.",
      isPopular: true
    },
    {
      icon: <Bath className="h-8 w-8" />,
      title: "Bathroom Vanities",
      description: "Elegant bathroom vanity tops and shower surrounds to enhance your bathroom's aesthetics."
    },
    {
      icon: <Scissors className="h-8 w-8" />,
      title: "Custom Stonework",
      description: "Unique custom stone applications including fireplace surrounds, tabletops, and decorative elements."
    },
    {
      icon: <Home className="h-8 w-8" />,
      title: "Outdoor Kitchens",
      description: "Weather-resistant stone surfaces for outdoor kitchens and entertainment areas."
    },
    {
      icon: <RefreshCw className="h-8 w-8" />,
      title: "Countertop Replacement",
      description: "Efficient removal and replacement of existing countertops with minimal disruption."
    },
    {
      icon: <Drill className="h-8 w-8" />,
      title: "Stone Repair",
      description: "Professional repair services for chipped, cracked, or damaged stone surfaces."
    }
  ];

  return (
    <section id="services" className="py-24 bg-white">
      <div className="container mx-auto px-4">
        {/* Section Divider */}
        <div className="flex items-center justify-center mb-12">
          <div className="flex-1 h-px bg-gradient-to-r from-transparent via-gray-300 to-transparent"></div>
          <div className="px-6">
            <div className="bg-primary text-white p-3 rounded-full">
              🛠️
            </div>
          </div>
          <div className="flex-1 h-px bg-gradient-to-r from-transparent via-gray-300 to-transparent"></div>
        </div>
        
        <div className="text-center max-w-3xl mx-auto mb-16 fade-in">
          <h2 className="text-4xl md:text-5xl lg:text-6xl font-bold text-primary mb-8">
            Our Premium Services
          </h2>
          <p className="text-gray-600 text-lg">
            We offer a comprehensive range of stone installation services to meet your residential 
            and commercial needs. Each project is handled with precision and care from start to finish.
          </p>
        </div>
        
        <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-6 sm:gap-8 md:gap-10">
          {services.map((service, index) => (
            <ServiceCard
              key={index}
              icon={service.icon}
              title={service.title}
              description={service.description}
              index={index}
              isPopular={service.isPopular}
            />
          ))}
        </div>
        
        <motion.div 
          className="text-center mt-16"
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.7, delay: 0.6 }}
          viewport={{ once: true }}
        >
          <a 
            href="#contact" 
            className="inline-flex items-center justify-center px-8 py-4 bg-primary text-white font-semibold rounded-lg shadow-lg hover:bg-primary/90 transition-all duration-300 transform hover:translate-y-[-2px]"
          >
            Schedule a Consultation
          </a>
        </motion.div>
      </div>
    </section>
  );
}